CreateLoggingServerRequest

Struct CreateLoggingServerRequest 

pub struct CreateLoggingServerRequest {
    pub parent: String,
    pub logging_server: Option<LoggingServer>,
    pub logging_server_id: String,
    pub request_id: String,
}
Request message for [VmwareEngine.CreateLoggingServer][google.cloud.vmwareengine.v1.VmwareEngine.CreateLoggingServer]

Fields

parent: String

Required. The resource name of the private cloud to create a new Logging Server in. Resource names are schemeless URIs that follow the conventions in https://cloud.google.com/apis/design/resource_names. For example: projects/my-project/locations/us-central1-a/privateClouds/my-cloud

logging_server: Option<LoggingServer>

Required. The initial description of a new logging server.

logging_server_id: String

Required. The user-provided identifier of the LoggingServer to be created. This identifier must be unique among LoggingServer resources within the parent and becomes the final token in the name URI. The identifier must meet the following requirements:

  • Only contains 1-63 alphanumeric characters and hyphens
  • Begins with an alphabetical character
  • Ends with a non-hyphen character
  • Not formatted as a UUID
  • Complies with RFC 1034 (section 3.5)
request_id: String

Optional. A request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server guarantees that a request doesn’t result in creation of duplicate commitments for at least 60 minutes.

For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).